@@ -2,12 +2,13 @@
 $image = \Blue2\Scruffy\Site::acfImage(get_sub_field('image')['id'], 'info-block-section');
 $title = get_sub_field('title');
 $description = get_sub_field('description');
+$id = get_sub_field('section_id');
 ?>
-<section class="custom-flexible-section info-block-section">
+<section class="custom-flexible-section info-block-section" id="<?= $id; ?>">
     <div class="contain">
         <div class="block-wrapper">
             <div class="row no-gutters row-eq-height">
-                <div class="col-lg-6 col-x-7">
+                <div class="col-lg-6 col-xl-7">
                     <div class="image-section <?= $image['class']; ?>">
                         <?= $image['output']; ?>
                     </div>
